@@ -99,6 +99,8 @@ class FigPager:
         sharex=False,
         sharey=False,
         draft=True,
+        wspace=0.2,
+        hspace=0.2,
     ):
 
         """
@@ -129,6 +131,8 @@ class FigPager:
             sharex: share x axes in subplots. Default is False
             sharey:share y axes in subplots. Default is False
             draft: Add draft stamp if available from ini. Default is True
+            wspace: Add height spacing for subplots adjust. Default is 0.2
+            hspace: Add horizontal spacing for subplots adjust. Default is 0.2
         """
 
         # obtain the caller path
@@ -229,6 +233,8 @@ class FigPager:
         self.sharex = sharex
         self.sharey = sharey
         self.draft = draft
+        self.wspace = wspace
+        self.hspace = hspace
 
         # figure attributes
         self.fig = None
@@ -280,6 +286,9 @@ class FigPager:
         # transform storage
         self.transform = None
 
+        # subplt counter storage
+        self.subplotcounter = 0
+
         # update from layout
         self._update_from_layout()
         # draw the initial page
@@ -1004,6 +1013,7 @@ class FigPager:
                 bottom=(self.bottommargin + self.marginpad) / self.pageheight_inch,
                 top=(self.frameheight + self.bottommargin - self.marginpad)
                 / self.pageheight_inch,
+                hspace=self.hspace, wspace=self.wspace,
             )
 
         # This resets the margins and other parameters to layout
@@ -1071,11 +1081,16 @@ class FigPager:
                         pos = [pos[0] + 1, 0]
 
                     else:
-                        # reset the starting position
+                        # save the starting position
                         pos = self.subplotstartindex
+
                         self.fig, self.ax, self.gs, self.transform = self.add_page(
                             subplotstartindex=self.subplotstartindex
                         )
+                        # reset the
+                        # self.subplotstartindex = pos
+                        self.currentsubplotindex = pos
+
 
             if self.direction == "top-to-bottom":
                 if self.subplotstartindex is None:
@@ -1100,15 +1115,21 @@ class FigPager:
                         self.fig, self.ax, self.gs, self.transform = self.add_page(
                             subplotstartindex=self.subplotstartindex
                         )
+
+                        # use the existing column and add a row
+                        self.subplotstartindex = [pos[0] + 1, pos[1]]
+
         else:
             self.subplotstartindex = pos
 
         self.currentsubplotindex = pos
+        # advance the subplot counter. Makes a unique subplot label
+        self.subplotcounter = self.subplotcounter + 1
 
         if gs is None:
             return self.fig.add_subplot(
                 self.gs[pos[0], pos[1]],
-                label="({},{})".format(pos[0], pos[1]),
+                label="({},{}, {})".format(pos[0], pos[1],  self.subplotcounter),
                 **kwargs
             )
         else:
@@ -1119,9 +1140,9 @@ class FigPager:
 
             return self.fig.add_subplot(
                 gs,
-                label="({},{})".format(
-                    self.currentsubplotindex[0], self.currentsubplotindex[1]
-                ),
+                label="({},{}, {})".format(
+                    self.currentsubplotindex[0], self.currentsubplotindex[1],
+                    self.subplotcounter),
                 **kwargs
             )
 
@@ -1144,6 +1165,8 @@ class FigPager:
         metadata=None,
         subplotstartindex=None,
         direction="left-to-right",
+        wspace=None,
+        hspace=None,
     ):
 
         """
@@ -1172,6 +1195,9 @@ class FigPager:
             defaults depend on the image format and backend:
             subplotstartindex: (list of ints) (optional) First subplot on a page row and column index.
             direction: (string) (optional) subplot creation direction. Default is Left-to-right.
+            gs: (optional) GridSpec specification for more advanced positions
+            wspace: Add height spacing for subplots adjust. Default is object's init
+            hspace: Add horizontal spacing for subplots adjust. Default is object's init
 
         Returns: fig; figure instance, ax; axes instances, gs; GridSpec, self.transform; Figure Transform
 
@@ -1267,13 +1293,19 @@ class FigPager:
         if metadata is not None:
             self.metadata = metadata
 
-        if subplotstartindex == [0, 0] or subplotstartindex is None:
+        if subplotstartindex is None:
             self.subplotstartindex = None
         else:
             self.subplotstartindex = subplotstartindex
 
         self.direction = direction
 
+        if wspace is not None:
+            self.wspace = wspace
+
+        if hspace is not None:
+            self.hspace = hspace
+
         if layout is not None:
             self.layout = layout
             self._read_layout(layout)
